#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from zope.interface import Interface

from pyams_content.shared.site.interfaces import IContentSummaryInfo, ISiteContainer
from pyams_content.shared.site.portlet import ISiteContainerSummaryPortletSettings
from pyams_portal.interfaces import IPortalContext, IPortletRenderer
from pyams_portal.portlet import PortletRenderer
from pyams_skin.layer import IPyAMSLayer
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config

from pyams_default_theme import _


@adapter_config(context=(IPortalContext, IPyAMSLayer, Interface, ISiteContainerSummaryPortletSettings),
                provides=IPortletRenderer)
@template_config(template='templates/site-summary.pt', layer=IPyAMSLayer)
class SiteContainerSummaryPortletDefaultRenderer(PortletRenderer):
    """Site container summary portlet default renderer"""

    label = _("Site container summary")

    @property
    def visible_items(self):
        container = ISiteContainer(self.context, None)
        if container is not None:
            registry = self.request.registry
            yield from filter(lambda x: x is not None,
                              [registry.queryMultiAdapter((item, self.request), IContentSummaryInfo)
                               for item in container.get_visible_items(self.request)])
